@@ -60,10 +60,10 @@ from sqlalchemy.schema import MetaData
 from . import fixtures
 from .query import Query, Future, NotFound
 from .serializers import to_json
-from .types import JSONEncodedType
+from .custom_types import JSONEncodedType
 
 
-__version__ = '1.1.10'
+__version__ = '1.1.12'
 
 
 def _create_scoped_session(db):
